package com.gic.plug.web.controller.goods;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.contants.SortType;
import com.gic.commons.util.PageHelperUtils;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.goods.api.dto.BrandDTO;
import com.gic.goods.api.dto.GoodsRightsSelectorDTO;
import com.gic.goods.api.service.BrandApiService;
import com.gic.goods.api.service.GoodsRightsSelectorApiService;
import com.gic.goods.api.util.Constant;
import com.gic.plug.web.vo.goods.GoodsBrandVO;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

@RestController
public class GoodsBrandController extends BaseGoodsController {

    @Autowired
    private BrandApiService brandApiService;

    @Autowired
    private GoodsRightsSelectorApiService goodsRightsSelectorApiService;

    @RequestMapping("/goods-brand-list")
    public RestResponse goodsBrandList(int pageSize, int currentPage, String search, Long goodsDomainId, String channelCode) {
        Long resourceId = UserDetailUtils.getUserDetail().getUserResourceInfo() == null ? null :
                UserDetailUtils.getUserDetail().getUserResourceInfo().getGoodsResourceId();
        ServiceResponse<GoodsRightsSelectorDTO> selectorDTOServiceResponse = goodsRightsSelectorApiService
                .getGoodsRightsSelector(resourceId, getEnterpriseId()
                , UserDetailUtils.getUserDetail().getUserInfo().getSuperAdmin());
        if (!selectorDTOServiceResponse.isSuccess() || selectorDTOServiceResponse.getResult() == null ||
                selectorDTOServiceResponse.getResult().getHasRights() == Constant.NO) {
            return RestResponse.success(Collections.EMPTY_LIST);
        }
        // 是否最高权限
        List<Long> branIdList = new ArrayList<>();
        if (UserDetailUtils.getUserDetail().getUserResourceInfo() != null
            && UserDetailUtils.getUserDetail().getUserResourceInfo().getGoodsResourceId() != null) {
            if (selectorDTOServiceResponse.isSuccess()) {
                GoodsRightsSelectorDTO goodsRightsSelectorDTO = selectorDTOServiceResponse.getResult();
                if (goodsRightsSelectorDTO != null) {
                    JSONObject brandRightsObject = JSONObject.parseObject(goodsRightsSelectorDTO.getGoodsRightsBrands());
                    JSONArray array = brandRightsObject.getJSONArray(channelCode + "_" + goodsDomainId);
                    if (CollectionUtils.isNotEmpty(array)) {
                        for (int i = 0; i < array.size(); i++) {
                            Long brandId = array.getLong(i);
                            branIdList.add(brandId);
                        }
                    }
                }
            }
        }
        return findBrandListByParams(currentPage, pageSize,goodsDomainId, search, getEnterpriseId());
    }


    /**
     * 权限商品筛选器的品牌接口
     * @param pageSize
     * @param currentPage
     * @param search
     * @param goodsDomainId
     * @return
     */
    @RequestMapping("/goods-brand-list-for-rights")
    public RestResponse goodsBrandListForRights(int pageSize, int currentPage, String search, Long goodsDomainId) {
        return findBrandListByParams(currentPage, pageSize,goodsDomainId, search, getEnterpriseId());
    }

    private RestResponse findBrandListByParams(int currentPage, int pageSize, Long goodsDomainId, String search, Integer enterpriseId) {
        List<Long> branIdList = new ArrayList<>();
        ServiceResponse<Page<BrandDTO>> serviceResponse = brandApiService.findBrandPage(currentPage, pageSize, goodsDomainId, search, branIdList, SortType.sortDescType, enterpriseId);
        if (!serviceResponse.isSuccess()) {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        Page<GoodsBrandVO> page = PageHelperUtils.changePageToCurrentPage(serviceResponse.getResult(), GoodsBrandVO.class);
        //TODO 品牌id的拼写错误
        for (int i = 0; i < page.getResult().size(); i++) {
            GoodsBrandVO goodsBrandVO = page.getResult().get(i);
            goodsBrandVO.setSpecBrandId(serviceResponse.getResult().getResult().get(i).getSepcBrandId());
        }
        return RestResponse.success(page);
    }

}
